@@ -16,7 +16,17 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+)
 
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
@@ -24,7 +34,8 @@ from google.api_core import retry as retries
 from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.vpcaccess_v1 import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -132,7 +143,7 @@ class VpcAccessServiceAsyncClient:
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -168,9 +179,9 @@ class VpcAccessServiceAsyncClient:
     def __init__(
         self,
         *,
-        credentials: ga_credentials.Credentials = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, VpcAccessServiceTransport] = "grpc_asyncio",
-        client_options: ClientOptions = None,
+        client_options: Optional[ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the vpc access service client.
@@ -214,13 +225,13 @@ class VpcAccessServiceAsyncClient:
 
     async def create_connector(
         self,
-        request: Union[vpc_access.CreateConnectorRequest, dict] = None,
+        request: Optional[Union[vpc_access.CreateConnectorRequest, dict]] = None,
         *,
-        parent: str = None,
-        connector_id: str = None,
-        connector: vpc_access.Connector = None,
+        parent: Optional[str] = None,
+        connector_id: Optional[str] = None,
+        connector: Optional[vpc_access.Connector] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Creates a Serverless VPC Access connector, returns an
@@ -252,13 +263,13 @@ class VpcAccessServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.vpcaccess_v1.types.CreateConnectorRequest, dict]):
+            request (Optional[Union[google.cloud.vpcaccess_v1.types.CreateConnectorRequest, dict]]):
                 The request object. Request for creating a Serverless
                 VPC Access connector.
             parent (:class:`str`):
@@ -352,11 +363,11 @@ class VpcAccessServiceAsyncClient:
 
     async def get_connector(
         self,
-        request: Union[vpc_access.GetConnectorRequest, dict] = None,
+        request: Optional[Union[vpc_access.GetConnectorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> vpc_access.Connector:
         r"""Gets a Serverless VPC Access connector. Returns NOT_FOUND if the
@@ -389,7 +400,7 @@ class VpcAccessServiceAsyncClient:
                 print(response)
 
         Args:
-            request (Union[google.cloud.vpcaccess_v1.types.GetConnectorRequest, dict]):
+            request (Optional[Union[google.cloud.vpcaccess_v1.types.GetConnectorRequest, dict]]):
                 The request object. Request for getting a Serverless VPC
                 Access connector.
             name (:class:`str`):
@@ -455,11 +466,11 @@ class VpcAccessServiceAsyncClient:
 
     async def list_connectors(
         self,
-        request: Union[vpc_access.ListConnectorsRequest, dict] = None,
+        request: Optional[Union[vpc_access.ListConnectorsRequest, dict]] = None,
         *,
-        parent: str = None,
+        parent: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListConnectorsAsyncPager:
         r"""Lists Serverless VPC Access connectors.
@@ -492,7 +503,7 @@ class VpcAccessServiceAsyncClient:
                     print(response)
 
         Args:
-            request (Union[google.cloud.vpcaccess_v1.types.ListConnectorsRequest, dict]):
+            request (Optional[Union[google.cloud.vpcaccess_v1.types.ListConnectorsRequest, dict]]):
                 The request object. Request for listing Serverless VPC
                 Access connectors in a location.
             parent (:class:`str`):
@@ -570,11 +581,11 @@ class VpcAccessServiceAsyncClient:
 
     async def delete_connector(
         self,
-        request: Union[vpc_access.DeleteConnectorRequest, dict] = None,
+        request: Optional[Union[vpc_access.DeleteConnectorRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
         r"""Deletes a Serverless VPC Access connector. Returns NOT_FOUND if
@@ -605,13 +616,13 @@ class VpcAccessServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = await operation.result()
+                response = (await operation).result()
 
                 # Handle the response
                 print(response)
 
         Args:
-            request (Union[google.cloud.vpcaccess_v1.types.DeleteConnectorRequest, dict]):
+            request (Optional[Union[google.cloud.vpcaccess_v1.types.DeleteConnectorRequest, dict]]):
                 The request object. Request for deleting a Serverless
                 VPC Access connector.
             name (:class:`str`):
@@ -695,10 +706,10 @@ class VpcAccessServiceAsyncClient:
 
     async def list_operations(
         self,
-        request: operations_pb2.ListOperationsRequest = None,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.ListOperationsResponse:
         r"""Lists operations that match the specified filter in the request.
@@ -749,10 +760,10 @@ class VpcAccessServiceAsyncClient:
 
     async def get_operation(
         self,
-        request: operations_pb2.GetOperationRequest = None,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operations_pb2.Operation:
         r"""Gets the latest state of a long-running operation.
@@ -803,10 +814,10 @@ class VpcAccessServiceAsyncClient:
 
     async def list_locations(
         self,
-        request: locations_pb2.ListLocationsRequest = None,
+        request: Optional[locations_pb2.ListLocationsRequest] = None,
         *,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> locations_pb2.ListLocationsResponse:
         r"""Lists information about the supported locations for this service.
@@ -862,14 +873,9 @@ class VpcAccessServiceAsyncClient:
         await self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-vpc-access",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("VpcAccessServiceAsyncClient",)
