@@ -931,7 +931,7 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         # Done; return the response.
         return response
 
-    def __enter__(self):
+    def __enter__(self) -> "VpcAccessServiceClient":
         return self
 
     def __exit__(self, type, value, traceback):
